<?php

namespace Drupal\openfed_migrate\Plugin\migrate\source\bean;

use Drupal\Core\Entity\EntityManagerInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\State\StateInterface;
use Drupal\migrate\Plugin\migrate\source\SqlBase;
use Drupal\migrate\Plugin\MigrationInterface;
use Drupal\migrate\Row;
use Drupal\migrate_drupal\Plugin\migrate\source\DrupalSqlBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Drupal 7 bean entity source from database.
 *
 * @MigrateSource(
 *   id = "d7_bean_type",
 *   source_module = "bean"
 * )
 */
class BeanType extends DrupalSqlBase {

  /**
   * The module handler.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, MigrationInterface $migration, StateInterface $state, EntityManagerInterface $entity_manager, ModuleHandlerInterface $module_handler) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $migration, $state, $entity_manager);
    $this->moduleHandler = $module_handler;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition, MigrationInterface $migration = NULL) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $migration,
      $container->get('state'),
      $container->get('entity.manager'),
      $container->get('module_handler')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function query() {
    // This query will allow us to avoid migrating beans without content which
    // usually means that this bean type is corrupt (probably due to features in
    // Drupal 7).
    $query = $this->select('bean', 'b');
    $query->leftJoin('bean_type', 'bt', 'bt.name = b.type');
    $query->addField('bt', 'label');
    $query->addField('bt', 'description');
    $query->addField('b', 'type', 'name');
    $query->groupBy('bt.label');
    $query->groupBy('bt.description');
    $query->groupBy('b.type');

    return $query;
  }

  /**
   * {@inheritdoc}
   * @throws \Exception
   */
  public function prepareRow(Row $row) {
    if (empty($row->getSourceProperty('label'))) {
      $row->setSourceProperty('label', ucfirst(str_replace('_', ' ', $row->getSourceProperty('name'))));
    }
    return parent::prepareRow($row); // TODO: Change the autogenerated stub
  }

  /**
   * {@inheritdoc}
   */
  public function fields() {
    return [
      'name' => $this->t('The bean type identifier'),
      'label' => $this->t('The bean type readable name'),
      'description' => $this->t('Bean type description.'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIds() {
    $ids['name']['type'] = 'string';
    return $ids;
  }

}
